# Version Changelog

## 0.1.4 (2020-04-11)

-   Fixed `SlashingAPI.signing_info_by_address` default argument function due to missing `None`-check.

## 0.1.3 (2020-04-11)

-   Remove debug print statement in `GovernanceAPI.proposals()`

## 0.1.2 (2020-03-20)

-   Fix `Dec` pretty-printing issue on Jupyter
-   Add `MsgInfosQuery.__contains__` support for Message classes

## 0.1.1 (2020-03-09)

-   Option to change coin type other than LUNA for MnemonicKey
-   Add `ParamChanges` to facilitate construction of `ParameterChangeProposal`s.

## 0.1.0 (2020-03-03)

-   Hello Jigu!
-   Let there be light

## 0.0.1 - 0.0.18 (2020-01-23)

-   Interface ideation
-   Primordial world
